Learn R Programming

rdrop2 (version 0.7.0)

drop_history: Obtains metadata for all available revisions of a file, including the current revision.

Description

Only revisions up to thirty days old are available (or more if the Dropbox user has Extended Version History). You can use the revision number in conjunction with the /restore call to revert the file to its previous state.

Usage

drop_history(path = NULL, dtoken = get_dropbox_token())

Arguments

path
This is required The path to the new folder to create relative to root.
dtoken
The Dropbox token generated by drop_auth. rdrop2 will try to automatically locate your local credential cache and use them. However, if the credentials are not found, the function will initiate a new authentication request. You can override this by pointing to a different location where your credentials are stored.

Examples

Run this code
## Not run: 
# write.csv(iris, file = "iris.csv")
# drop_upload("iris.csv")
# write.csv(iris[iris$Species == "setosa", ], file = "iris.csv")
# drop_upload("iris.csv")
# drop_history("iris.csv")
# ## End(Not run)

Run the code above in your browser using DataLab